@@ -15,8 +15,9 @@ class GatedHead(EncoderHead):
         self.gates = Parameter(torch.Tensor(self.input_embedding_size))
         self.reset_parameters()
 
+    @property
     def output_size(self) -> int:
-        return self.vector_size
+        return self.input_embedding_size
 
     def forward(self, input_vectors: torch.Tensor) -> torch.Tensor:
         """
